package com.ghy.goods.mapper;

import com.ghy.goods.domain.DeptGoodsCategory;
import org.apache.ibatis.annotations.Param;

import java.util.Collection;
import java.util.List;

/**
 * 分公司使用类目mapper
 *
 * @author clunt
 */
public interface DeptGoodsCategoryMapper {

    /**
     * @param category 商品属性
     * @return 成功条数
     */
    int insertDeptGoodsCategory(DeptGoodsCategory category);

    /**
     * @param category 商品属性
     * @return 成功条数
     */
    int updateDeptGoodsCategory(DeptGoodsCategory category);

    /**
     * @param category 商品入参
     * @return 商品集合
     */
    List<DeptGoodsCategory> selectList(DeptGoodsCategory category);


    /**
     * @param goodsCategoryId 商品id
     * @return 商品
     */
    DeptGoodsCategory selectById(Long goodsCategoryId);

    /**
     * 批量删除商品信息
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    int deleteDeptGoodsCategoryByIds(@Param("ids") Collection<Long> ids);


    List<DeptGoodsCategory> appList(DeptGoodsCategory deptGoodsCategory);

    /**
     * 用商品类目ID查一条分公司类目
     *
     * @param goodsCategoryId 商品类目
     */
    DeptGoodsCategory selectOneByGoodsCategoryId(Long goodsCategoryId);

    /**
     * 用分公司ID查询
     *
     * @param deptId 分公司ID
     */
    List<DeptGoodsCategory> selectByDeptId(Long deptId);

    /**
     * 删除
     */
    int deleteById(Long id);

}
